@@ -1,7 +1,6 @@
 #[cfg(all(feature = "nightly", test))]
 extern crate test;
 
-use std::fs::OpenOptions;
 use std::mem::{size_of, transmute};
 use std::path::PathBuf;
 use std::sync::atomic::{AtomicU64, Ordering};
@@ -10,7 +9,7 @@ use std::sync::{Arc, Mutex, RwLock, RwLockReadGuard};
 use anyhow::Result;
 use memmap2::MmapMut;
 
-use crate::Cache;
+use crate::{Cache, CacheStore};
 
 type OnSizeChange = fn(old_size: usize, new_size: usize) -> ();
 
@@ -87,11 +86,7 @@ fn resize_and_memmap(index: usize, opts: &DenseFileCacheOpts) -> Result<MmapMut>
             size_of::<usize>()
         )
     }
-    let file = OpenOptions::new()
-        .read(true)
-        .write(true)
-        .create(true)
-        .open(opts.filename.as_ref())?;
+    let file = crate::open_cache_file(opts.filename.as_ref())?;
     let old_size = file.metadata().unwrap().len();
 
     let capacity = (index + 1) * size_of::<usize>();
@@ -143,15 +138,16 @@ impl DenseFileCache {
             mutex: Arc::new(Mutex::new(())),
         })
     }
+}
 
-    /// Create a thread-safe caching accessor
-    pub fn get_accessor(&self) -> impl Cache + '_ {
+impl CacheStore for DenseFileCache {
+    fn get_accessor(&self) -> Box<dyn Cache + '_> {
         let (mm_setter, raw_data) = lock_and_link(&self.memmap);
-        CacheWriter {
+        Box::new(CacheWriter {
             parent: self,
             mm_setter,
             raw_data,
-        }
+        })
     }
 }
 
@@ -210,11 +206,10 @@ mod tests {
     use std::fs;
     use std::path::PathBuf;
 
-    use rand::seq::SliceRandom;
-    use rand::thread_rng;
     use rayon::iter::ParallelBridge;
     use rayon::iter::ParallelIterator;
 
+    use crate::tests::get_random_items;
     use crate::*;
 
     #[test]
@@ -247,12 +242,6 @@ mod tests {
         }
         let _ = fs::remove_file(test_file);
     }
-
-    fn get_random_items(items: usize) -> Vec<usize> {
-        let mut vec: Vec<usize> = (0_usize..items).collect();
-        vec.shuffle(&mut thread_rng());
-        vec
-    }
 }
 
 /// The benchmarks require nightly to run:
